-- ---------------------------------------------------------
-- data pack install script example
--
-- proper regions of France including overseas territories
-- license: GPL v2 or later
-- provided by Francois M <francoismalias-forum@yahoo.fr>
--
-- http://wiki.gnumed.de/bin/view/Gnumed/GmManualReferenceData
--
-- somewhat official region codes can be found here:
--		http://www.insee.fr/fr/methodes/nomenclatures/cog/region.asp
-- but they are hardly useful outside the French Statistics Institute
-- ---------------------------------------------------------

-- enable these if running locally via
-- psql -d gnumed_vXX -U gm-dbo -f install-data-pack.sql
--SET default_transaction_read_only TO OFF;

SET client_encoding to 'utf8';

-- ---------------------------------------------------------
-- drop staging tables if needed
\unset ON_ERROR_STOP
DROP table staging.french_regions cascade;
\set ON_ERROR_STOP 1

-- ---------------------------------------------------------
-- run everything else in one transaction
BEGIN;

-- create staging tables as needed
CREATE TABLE staging.french_regions (
	code text,
	region text
);

-- remove unused French regions
-- this will also remove:
--    (RI   | FR      | Riviera     > NOT A REGION)
-- unless that is already in use ...
DELETE FROM dem.state d_st
WHERE
	country = 'FR'
		AND
	NOT EXISTS (
		SELECT 1 FROM dem.urb d_u
		WHERE d_u.id_state = d_st.id
	)
;

select * from dem.state where country = 'FR';

-- load master staging table
INSERT INTO staging.french_regions (code, region) VALUES
	('AL', 'Alsace'),
	('AQ', 'Aquitaine'),
	('AU', 'Auvergne'),
	('BR', 'Bretagne'),
	('BU', 'Bourgogne'),
	('CE', 'Centre'),
	('CH', 'Champagne-Ardenne'),
	('CO', 'Corse'),
	('FR', 'Franche Comte'),
	('LA', 'Languedoc Roussillon'),
	('LI', 'Limousin'),
	('LO', 'Lorraine'),
	('MI', 'Midi-Pyrenees'),
	('NO', 'Nord-Pas-de-Calais'),
	('NR', 'Basse-Normandie'),
	('HN', 'Haute-Normandie'),
	('PA', 'Ile-de-France'),
	('PI', 'Picardie'),
	('PO', 'Poitou-Charentes'),
	('PR', 'Provence-Alpes-Cote d''Azur'),
	('RH', 'Rhone-Alpes'),
	('WE', 'Pays de la Loire'),
	('OM-GU', 'Guadeloupe (DOM)'),
	('OM-GY', 'Guyane (DOM)'),
	('OM-MA', 'Martinique (DOM)'),
	('OM-MY', 'Mayotte (DOM)'),
	('OM-LR', 'La Reunion (DOM)'),
	('??', 'état/territoire/province/région inconnu')
;

SELECT i18n.upd_tx('fr', 'state/territory/province/region not available', 'état/territoire/province/région inconnu');


-- update existing regions
UPDATE dem.state d_st SET
	name = (SELECT region FROM staging.french_regions s_fr WHERE s_fr.code = d_st.code)
WHERE
	d_st.country = 'FR'
;

select * from dem.state where country = 'FR';

-- remove updated regions from staging
DELETE FROM staging.french_regions s_fr
WHERE EXISTS (
	SELECT 1 FROM dem.state d_st
	WHERE
		d_st.country = 'FR'
			AND
		d_st.code = s_fr.code
);

select * from dem.state where country = 'FR';

-- insert new regions
INSERT INTO dem.state (country, code, name)
	SELECT
		'FR'::char(2),
		s_fr.code,
		s_fr.region
	FROM
		staging.french_regions s_fr
	-- this really should be redundant but better safe than sorry:
	WHERE NOT EXISTS (
		SELECT 1 FROM dem.state d_st
		WHERE
			d_st.country = 'FR'
				AND
			d_st.code = s_fr.code
	)
;

select * from dem.state where country = 'FR';

-- drop staging tables again
\unset ON_ERROR_STOP
DROP table staging.french_regions cascade;
\set ON_ERROR_STOP 1


-- finalize transaction --
-- uncomment this once you are satisfied your script works:
COMMIT;
-- ---------------------------------------------------------
